@@ -15,7 +15,8 @@ class CardToken:
             'Cache-Control': 'no-cache'
         }
 
-    def create(self, card_id: int):
+    def create(self, card: dict):
+        card_id = card['decidir_id'] if 'decidir_id' in card else card['id']
         body = {
             'token': card_id,
             'security_code': '999'
