@@ -37,7 +37,9 @@ class Payment:
         }
         r = requests.post(self.url + '/payments', headers=self.headers, data=json.dumps(body))
         if r.status_code < 400:
-            return ok(r.json())
+            response = r.json()
+            response['processor'] = 'decidir'
+            return ok(response)
         return error(r.json())
 
     def get(self, payment_id: int):
