@@ -7,8 +7,11 @@ class CardToken:
     def __init__(self, sdk: mercadopago.SDK):
         self.sdk = sdk
 
-    def create(self, card_id: int):
-        data = {"card_id": card_id}
+    def create(self, card: dict):
+        card_id = card['mercadopago_id'] if 'decidir_id' in card else card['id']
+        data = {
+            "card_id": card_id
+        }
         card_token_response = self.sdk.card_token().create(data)
 
         if card_token_response["status"] > 299:
